# About this directory

This directory contains mocks for pywin32 classes.
It is used so that the documentation can build on non Windows operating system
like Linux.

**DON'T EXPECT ANY FUNCTIONALITY HERE!!**